% Written by Marcus Boden. For feedback or comments on this class contact me at  marcus.boden@posteo.de
\ProvidesClass{bio-bachelor}[2014/10/15]
\usepackage[T1]{fontenc}
\usepackage[utf8x]{inputenc}
\usepackage{etoolbox}
\usepackage[english,ngerman]{babel}
\usepackage{graphicx}
\usepackage{tabularx}
\usepackage{xkeyval}



\newcommand{\@lang}{german}

\newcommand*{\@clearpagesection}{\cleardoublepage}

\DeclareOptionX*{\PassOptionsToClass{\CurrentOption}{scrartcl}}
\DeclareOptionX{clearsectionpage}{
	\ifstrempty{#1}{\renewcommand*{\@clearpagesection}{\cleardoublepage}}{
		\ifstrequal{single}{#1}{\renewcommand*{\@clearpagesection}{\clearpage}}{
			\ifstrequal{double}{#1}{\renewcommand*{\@clearpagesection}{\cleardoublepage}}{
				\ifstrequal{none}{#1}{}
			}
		}
	}
}
\DeclareOptionX{english}{\renewcommand{\@lang}{english}}
\DeclareOptionX{german}{\renewcommand{\@lang}{german}}
\DeclareOptionX{ngerman}{\renewcommand{\@lang}{german}}
\ProcessOptionsX

\LoadClass[a4paper]{scrartcl}

\renewcommand\section{\@clearpagesection%
  \@startsection{section}{\sectionnumdepth}{\z@}%
  {-3.5ex \@plus -1ex \@minus -.2ex}%
  {2.3ex \@plus.2ex}%
  {\ifnum \scr@compatibility>\@nameuse{scr@v@2.96}\relax
    \setlength{\parfillskip}{\z@ plus 1fil}\fi
    \raggedsection\normalfont\sectfont\nobreak\size@section}%
}

% Set parameters
\newcommand{\@institut}{Unknown}
\newcommand{\institut}[1]{\renewcommand{\@institut}{#1}}

\newcommand{\@erstbetreuer}{Unknown}
\newcommand{\erstbetreuer}[1]{\renewcommand{\@erstbetreuer}{#1}}

\newcommand{\@zweitbetreuer}{Unknown}
\newcommand{\zweitbetreuer}[1]{\renewcommand{\@zweitbetreuer}{#1}}

\newcommand{\@geburtsort}{Unknown}
\newcommand{\geburtsort}[1]{\renewcommand{\@geburtsort}{#1}}

\newcommand{\@semester}{Not specified}
\newcommand{\semester}[1]{\renewcommand{\@semester}{#1}}

\newcommand{\@abgabedatum}{Not specified}
\newcommand{\abgabedatum}[1]{\renewcommand{\@abgabedatum}{#1}}

\newcommand{\maketitlepage}{
	\Large\centering
		{\Huge \textbf{\@title}\\[0.5cm]}	
		\rule{\linewidth}{0.5mm}\\%
		\vspace{1cm}%
\ifdefstring{\@lang}{english}{%
		{\LARGE Bachelor thesis}\\[0.5cm]in the subject \textit{B.Sc. Biology}\\ submitted by\\[0.5cm]

		{\huge\textbf \@author}\\[0.5cm]
		from\\[0.2cm]
		{\LARGE \@geburtsort}\\\vfill
		written at the\\
		\@institut\\[1cm]
		at the Faculty of Biology and Psychology \\of the Georg-August-Universität in Göttingen\\
		\rule{\linewidth}{0.5mm}\\
		Submission in \@semester%
}{%
		{\LARGE Bachelorarbeit}\\[0.5cm]im Studiengang \textit{B.Sc. Biologie}\\vorgelegt von\\[0.5cm]

		{\huge\textbf \@author}\\[0.5cm]
		aus\\[0.2cm]
		{\LARGE \@geburtsort}\\\vfill
		angefertigt am\\
		\@institut\\[0.5cm]
		an der Fakultät für Biologie und Psychologie \\der Georg-August-Universität zu Göttingen\\
		\rule{\linewidth}{0.5mm}\\
		Abgabe im \@semester%
}}

\newcommand{\makesecondpage}{%
	\begin{center}%
	\framebox[1.1\width]{%
	\begin{minipage}{0.8\textwidth}
	\vspace*{0.5cm}
	\ifdefstring{\@zweitbetreuer}{Unknown}{%
		\ifdefstring{\@lang}{german}{%
			\begin{tabularx}{\textwidth}{@{}lX@{}}
				Betreuer: & \raggedright\arraybackslash\@erstbetreuer\\[0.5cm]
				Abgabetag: & \raggedright\arraybackslash\@abgabedatum
			\end{tabularx}
		}{\begin{tabularx}{\textwidth}{@{}lX@{}}
				Supervisor: & \raggedright\arraybackslash\@erstbetreuer\\[0.5cm]
				Submission date: & \raggedright\arraybackslash\@abgabedatum
			\end{tabularx}
		}
	}{%
		\ifdefstring{\@lang}{german}{%
			\begin{tabularx}{\textwidth}{@{}lX@{}}
				Erstbetreuer: & \raggedright\arraybackslash\@erstbetreuer\\[0.4\baselineskip]
				Zweitbetreuer: & \raggedright\arraybackslash\@zweitbetreuer\\[0.5cm]
				Abgabetag: & \raggedright\arraybackslash\@abgabedatum
			\end{tabularx}
		}{\begin{tabularx}{\textwidth}{@{}lX@{}}
				First Supervisor: & \raggedright\arraybackslash\@erstbetreuer\\[0.4\baselineskip]
				Second Supervisor: & \raggedright\arraybackslash\@zweitbetreuer\\[0.5cm]
				Submission date: & \raggedright\arraybackslash\@abgabedatum
			\end{tabularx}
		}
	}
	\vspace*{0.5cm}
	\end{minipage}}
	\end{center}
}

\renewcommand{\maketitle}{%
	\ifdefstring{\@lang}{german}{\selectlanguage{ngerman}}{\selectlanguage{english}}%
	\begin{titlepage}%
		\maketitlepage
		\cleardoublepage
	\end{titlepage}%
	\thispagestyle{empty}
	\makesecondpage
	\cleardoublepage
	\global\let\thanks\relax%
	\global\let\maketitle\relax%
	\global\let\@thanks\@empty%
	\global\let\@date\@empty%
	\global\let\@institut\@empty%
	\global\let\@erstbetreuer\@empty%
	\global\let\@zweitbetreuer\@empty%
	\global\let\@semester\@empty%
	\global\let\@geburtsort\@empty%
	\global\let\institut\relax%
	\global\let\erstbetreuer\relax%
	\global\let\zweitbetreuer\relax%
	\global\let\semester\relax%
	\global\let\geburtsort\relax%
	\global\let\abgabedatum\relax%
	\global\let\title\relax%
	\global\let\author\relax%
	\global\let\date\relax%
	\global\let\and\relax%
}

\newcommand{\selbststaendigkeitserklaerung}{
	\@clearpagesection
	\selectlanguage{ngerman}
	\thispagestyle{empty}
	%\onehalfspacing
	\begin{center}
		\includegraphics[width=0.8\textwidth]{logo-uni}\\[1cm]
		{\LARGE Prüfungsamt Biologie und Psychologie}\\[0.5cm]
		{\Large Selbstständigkeitserklärung}\\[1.5cm]
	\end{center}
	\raggedright\large
	Ich,\\[\baselineskip]
	{\centering\textbf{\@author}\\[\baselineskip]}
	versichere, dass ich die vorliegende Bachelorarbeit mit dem Titel:\\[\baselineskip]
	{\centering\textbf{\@title}\\[\baselineskip]}
	selbstständig verfasst und keine anderen als die angegebenen Quellen und Hilfsmittel benutzt habe.\\[2cm]
	\begin{minipage}[c]{0.4\textwidth}
		Göttingen, den \@abgabedatum\\
	\end{minipage}\hfill
	\begin{minipage}[t]{0.5\textwidth}
		\rule{\textwidth}{1pt}\\
		\raggedleft\@author
	\end{minipage}
}

\newcommand{\maketitleandtoc}{
	\maketitle
	\tableofcontents
	\thispagestyle{empty}
	\cleardoublepage
	\setcounter{page}{1}
}